@@ -1,4 +1,5 @@
 import logging
+from datetime import datetime
 from typing import Optional
 
 import aiohttp
@@ -57,7 +58,11 @@ class _APIClient:
             raise NoUserAgentSetError()
 
         self.session = aiohttp.ClientSession(
-            headers={"User-Agent": Client.USER_AGENT + " | via py-tmio"},
+            headers={
+                "Accept": "application/json",
+                "Content-Type": "application/json",
+                "User-Agent": Client.USER_AGENT + " | via py-tmio",
+            },
             **session_kwargs,
         )
 
@@ -103,15 +108,20 @@ class _APIClient:
             _log.info(f"Sending {method.upper()} to {endpoint}")
             try:
                 if "trackmania.io" in endpoint:
-                    Client.RATELIMIT_LIMIT = int(
-                        resp.headers.get("x-ratelimit-limit")[0]
-                    )
+                    Client.RATELIMIT_LIMIT = int(resp.headers.get("X-Ratelimit-Limit"))
                     Client.RATELIMIT_REMAINING = int(
-                        resp.headers.get("x-ratelimit-remaining")[0]
+                        resp.headers.get("X-Ratelimit-Remaining")
                     )
+                    Client.RATELIMIT_RESET = datetime.utcfromtimestamp(
+                        float(resp.headers.get("X-Ratelimit-Reset"))
+                    )
+
             except (AttributeError, TypeError):
                 pass
-            return await resp.json()
+            try:
+                return await resp.json()
+            except:
+                return await resp.text()
 
     async def get(
         self,
